#!/usr/bin/bash

# -- Product Class ------------------------------------------------------------

product.set() {
    function __in_array() { local a=${@:2}; [[ ${a[*]} == *${1}* ]]; return ${?}; }

    function _validate_product() {
        local _retval

        __in_array ${product} "${_PRODUCTS[@]}"
        _retval=${?}
        [[ ${_retval} -ne 0 ]] && \
            printf \
                $"Invalid product: %s\n" \
                ${product} && \
            exit ${_retval}
        return 0
    }

    function _get_source() {
        local _path _serie _source _status

        local _str=${_PRODUCTS[*]}
        local _regex="${product}:([a-zA-Z0-9_\/\.\+\-]*)"
        [[ ${_str} =~ ${_regex} ]]

        _path=${BASH_REMATCH[@]:1}
        _serie=$(basename ${_path})
        serie=${_serie}

        _source=$(
            printf \
                'https://%s%s/%s/%s/%s-%s.%s.tar.gz\n' \
                ${DOWNLOAD_SERVER} \
                $(dirname ${_path}) \
                ${_serie} \
                ${version} \
                ${product,,} \
                ${_serie} \
                ${version}
            )
        
        _status=$(
            wget \
                -qS \
                -O /dev/null \
                ${_source}.checksum \
                2>&1 | awk '/HTTP\/.*/ {print $2}'
            )

        [[ ${_status} -ne 200 ]] && \
            printf \
                $"Invalid source for product (%s): %s: No checksum file found.\n" \
                ${product} \
                ${version} && \
            exit ${_status}
        source=${_source}
        return 0
    }

    function _init() {
        _validate_product
        _get_source
    }


    declare -a _PRODUCTS=(
        'SIGERP:/produtos/sigerp/7.0'
        'SIGPDV:/produtos/sigpdv/3.1'
    )

    _init
}

product.upgrade() {
    source "${_libdir}/${product,,}.bash"
    ${product,,}.backup
    ${product,,}.install
    echo
}

# vim: ts=4:sw=4:sts=4:et
